@@ -205,10 +205,11 @@ setGeneric("getDesign", function(object, ...) standardGeneric("getDesign"))
 #' Extract Design from a CrossoverSearchResult
 #' 
 #' @name getDesign
-#' @aliases getDesign,CrossoverSearchResult-method getDesign getDesign,matrix-method
+#' @aliases getDesign,CrossoverSearchResult-method getDesign getDesign,matrix-method getDesign,character-method
 #' @param object A searchCrossOverDesign object from which the design should be extracted.
 #' @param ... Possible parameters for subclasses (not yet used).
 #' @return Returns a numeric matrix representing the crossover design.
+#' Rows represent periods, columns represent sequences.
 #' @author Kornelius Rohmeyer \email{rohmeyer@@small-projects.de}
 #' @examples
 #' 
@@ -216,6 +217,8 @@ setGeneric("getDesign", function(object, ...) standardGeneric("getDesign"))
 #' x <- searchCrossOverDesign(s=9, p=5, v=4, model=4, n=c(100,10))
 #' getDesign(x)
 #' 
+#' getDesign("williams4t")
+#' 
 #' @export
 #' @docType methods
 #' @rdname getDesign-methods
@@ -227,4 +230,12 @@ setMethod("getDesign", c("CrossoverSearchResult"),
 setMethod("getDesign", c("matrix"),
           function(object, ...) {  		
             return(object)
-          })
\ No newline at end of file
+          })
+
+setMethod("getDesign", c("character"),
+          function(object, ...) {    	
+            design <- get(object, envir=Crossover.env)            
+            rownames(design) <- paste("p", 1:dim(design)[1], sep="")
+            colnames(design) <- paste("s", 1:dim(design)[2], sep="")
+            return(design)
+          })
